#!/usr/bin/expect -f

# 获取命令行参数中的 hosts_file 文件名
set hosts_file [lindex $argv 0]

if {[llength $argv] != 1} {
    puts "Usage: $argv0 <hosts_file>"
    exit 1
}

# 设置 SSH 密钥对生成的参数
set ssh_keyfile "~/.ssh/id_rsa"
set ssh_keygen_cmd "ssh-keygen -t rsa -N '' -f $ssh_keyfile"

# 生成 SSH 密钥对（如果不存在）
spawn $ssh_keygen_cmd
expect {
    "Overwrite (y/n)?" {
        send "n\r"
        exp_continue
    }
    "Enter passphrase (empty for no passphrase):" {
        send "\r"
        exp_continue
    }
    "Enter same passphrase again:" {
        send "\r"
        exp_continue
    }
    eof
}

puts "SSH key pair generated."

# 读取目标主机列表（假设目标主机列表保存在 hosts_file 文件中）
set f [open $hosts_file "r"]
set hosts [split [read $f] "\n"]
close $f

# 为每个主机添加 SSH 指纹
foreach host $hosts {
    set ssh_copy_id_cmd "ssh-copy-id -f -i $ssh_keyfile.pub root@$host"

    spawn $ssh_copy_id_cmd
    expect {
        "Are you sure you want to continue connecting (yes/no)?" {
            send "yes\r"
            exp_continue
        }
        "Password:" {
            send "your_root_password\r"
            exp_continue
        }
        eof
    }

    puts "SSH fingerprint added for $host."
}

